import { updates } from '@/data/updates'
import Link from 'next/link'
import ReactMarkdown from 'react-markdown'
import DateDisplay from '@/components/DateDisplay'

export function generateStaticParams() {
  return updates.map((post) => ({
    id: post.id.toString(),
  }))
}

export default function BlogPost({ params }) {
  const post = updates.find((p) => p.id.toString() === params.id)

  if (!post) {
    return (
      <div className="container py-24">
        <h1 className="text-2xl font-bold">Post not found</h1>
        <Link href="/" className="text-blue-500 hover:underline">
          Back to home
        </Link>
      </div>
    )
  }

  return (
    <article className="container py-24">
      <Link href="/" className="text-blue-500 hover:underline mb-8 block">
        ← Back to home
      </Link>
      
      <header className="mb-8">
        <h1 className="text-4xl font-bold mb-4">{post.title}</h1>
        
        <div className="flex items-center gap-4 mb-6 p-4 border border-gray-800 rounded-lg">
          <img
            src={post.author.avatar}
            alt={post.author.name}
            className="w-16 h-16 rounded-full"
            width={64}
            height={64}
          />
          <div>
            <h3 className="text-lg font-semibold">{post.author.name}</h3>
            <p className="text-gray-400 text-sm mb-1">{post.author.role}</p>
            <p className="text-gray-400 text-sm">{post.author.bio}</p>
          </div>
        </div>
        
        <DateDisplay 
          timestamp={post.timestamp} 
          className="text-gray-400"
        />
      </header>

      <div className="prose prose-invert max-w-none">
        <ReactMarkdown
          components={{
            h1: ({children}) => <h1 className="text-3xl font-bold mt-8 mb-4">{children}</h1>,
            h2: ({children}) => <h2 className="text-2xl font-bold mt-6 mb-3">{children}</h2>,
            h3: ({children}) => <h3 className="text-xl font-bold mt-4 mb-2">{children}</h3>,
            p: ({children}) => <p className="mb-4">{children}</p>,
            ul: ({children}) => <ul className="list-disc ml-6 mb-4">{children}</ul>,
            ol: ({children}) => <ol className="list-decimal ml-6 mb-4">{children}</ol>,
            li: ({children}) => <li className="mb-1">{children}</li>,
            a: ({href, children}) => (
              <Link href={href} className="text-blue-500 hover:underline">
                {children}
              </Link>
            ),
            strong: ({children}) => <strong className="font-bold">{children}</strong>,
          }}
        >
          {post.content}
        </ReactMarkdown>
      </div>
    </article>
  )
}
