"use client";

import React, { useState, useEffect } from 'react'
import {
    Dialog,
    DialogContent,
    DialogDescription,
    DialogHeader,
    DialogTitle,
    DialogTrigger,
} from "@/components/ui/dialog"
import { ScrollArea } from "@/components/ui/scroll-area"
import { Table, TableBody, TableCell, TableHead, TableHeader, TableRow } from "@/components/ui/table"
import { List } from 'lucide-react'

export function DirectoryModal() {
    const [extensions, setExtensions] = useState([]);
    const [summary, setSummary] = useState({ total: 0, connected: 0, avgLatency: 0 });
    const [lastUpdated, setLastUpdated] = useState('');

    useEffect(() => {
        const fetchDirectory = async () => {
            try {
                const response = await fetch('https://corsproxy.io/?url=https://pbx.litenet.tel/status/');
                const text = await response.text();
                const parser = new DOMParser();
                const doc = parser.parseFromString(text, 'text/html');

                // Parse summary data
                const summaryText = doc.querySelector('h2.text-center')?.textContent;
                if (summaryText) {
                    const match = summaryText.match(/(\d+) Endpoints connected to (\d+) Extensions. With an average latency of ([\d.]+)ms/);
                    if (match) {
                        setSummary({
                            total: parseInt(match[1]),
                            connected: parseInt(match[2]),
                            avgLatency: parseFloat(match[3])
                        });
                    }
                }

                // Parse last updated time
                const timestampElement = doc.getElementById('timestamp');
                if (timestampElement) {
                    setLastUpdated(timestampElement.textContent || '');
                }

                // Parse extensions
                const rows = doc.querySelectorAll('table tbody tr');
                const parsedExtensions = Array.from(rows).map(row => {
                    const cells = row.querySelectorAll('td');
                    return {
                        number: cells[0].textContent?.replace('●', '').trim() || '',
                        name: cells[1].textContent || '',
                        status: cells[2].textContent || '',
                        endpoints: cells[3].textContent || '',
                        latency: cells[4].textContent || '',
                    };
                });
                setExtensions(parsedExtensions);
            } catch (error) {
                console.error('Error fetching directory:', error);
            }
        };

        fetchDirectory();
    }, []);

    return (
        <Dialog>
            <DialogTrigger asChild>
                <button className="inline-flex items-center justify-center rounded-md text-sm font-medium ring-offset-background transition-colors focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2 disabled:pointer-events-none disabled:opacity-50 border border-input bg-background hover:bg-accent hover:text-accent-foreground h-10 px-4 py-2">
                    <List className="mr-2 h-4 w-4" />
                    Show Directory
                </button>
            </DialogTrigger>
            <DialogContent className="sm:max-w-[800px] bg-black text-white border border-gray-800">
                <DialogHeader>
                    <DialogTitle className="text-2xl font-bold">LiteNet Directory</DialogTitle>
                    <DialogDescription className="text-gray-400">
                        {summary.total} Endpoints connected to {summary.connected} Extensions. Average latency: {summary.avgLatency.toFixed(2)}ms
                    </DialogDescription>
                </DialogHeader>
                <ScrollArea className="h-[400px] w-full rounded-md border border-gray-800 p-4">
                    <Table>
                        <TableHeader>
                            <TableRow>
                                <TableHead className="text-white">Extension</TableHead>
                                <TableHead className="text-white">Name</TableHead>
                                <TableHead className="text-white">Status</TableHead>
                                <TableHead className="text-white">Endpoints</TableHead>
                                <TableHead className="text-white">Latency</TableHead>
                            </TableRow>
                        </TableHeader>
                        <TableBody>
                            {extensions.map((ext) => (
                                <TableRow key={ext.number}>
                                    <TableCell className="font-medium">{ext.number}</TableCell>
                                    <TableCell>{ext.name}</TableCell>
                                    <TableCell>{ext.status}</TableCell>
                                    <TableCell>{ext.endpoints}</TableCell>
                                    <TableCell>{ext.latency}</TableCell>
                                </TableRow>
                            ))}
                        </TableBody>
                    </Table>
                </ScrollArea>
                <div className="text-sm text-gray-400">{lastUpdated}</div>
            </DialogContent>
        </Dialog>
    )
}