import { Phone, Users, VoicemailIcon, Radio, MoreHorizontal, Network, Bot, UserCog } from 'lucide-react'
import Link from 'next/link'

const features = [
  {
    name: 'Free Dial-in and Out',
    description: 'Call using +1 (610) LITENET / +1 (610) 548 3638',
    icon: Phone,
  },
  {
    name: 'Conference Rooms',
    description: 'Host or join conference calls with multiple participants',
    icon: Users,
  },
  {
    name: 'Voicemail',
    description: 'Set up your own private voicemail and receive messages from anyone',
    icon: VoicemailIcon,
  },
  {
    name: 'Intercom and Paging',
    description: 'Easily communicate with other extensions and page groups',
    icon: Radio,
  },
  {
    name: <>Access to <Link href="https://astrocom.tel/" className="text-xl font-semibold underline underline-offset-4 text-gray-300">AstroCom</Link></>,
    description: <>Dial directly to AstroCom straight from your LiteNet extension!</>,
    icon: Network,
  },
  {
    name: 'Discord Bot',
    description: 'Quickly create your own extension, manage page groups, and view Call Detail Records',
    icon: Bot,
  },
  {
    name: 'UCP Account',
    description: 'Log in to the User Control Panel to manage your account and settings',
    icon: UserCog,
  },
  {
    name: 'And More!',
    description: 'We\'re always adding new features to LiteNet!',
    icon: MoreHorizontal,
  },
]

export default function Features() {
  return (
    (<section id="features" className="container py-24">
      <h2 className="mb-12 text-center text-3xl font-bold">Features</h2>
      <div className="grid gap-8 sm:grid-cols-2 lg:grid-cols-3">
        {features.map((feature) => (
          <div key={feature.name} className="flex flex-col items-center text-center">
            <div className="mb-4 rounded-full bg-blue-500 p-3">
              <feature.icon className="h-6 w-6 text-gray-100" />
            </div>
            <h3 className="mb-2 text-xl font-semibold">{feature.name}</h3>
            <p className="text-gray-400">{feature.description}</p>
          </div>
        ))}
      </div>
    </section>)
  );
}

