"use client";

import React from 'react'
import {
    Dialog,
    DialogContent,
    DialogDescription,
    DialogHeader,
    DialogTitle,
    DialogTrigger,
} from "@/components/ui/dialog"
import { ScrollArea } from "@/components/ui/scroll-area"

export function PrivacyPolicyModal() {
    React.useEffect(() => {
        if (window.location.hash === '#privacy') {
            document.getElementById('privacy-trigger').click();
        }
    }, []);
    return (
        <Dialog>
            <DialogTrigger asChild>
                <button id="privacy-trigger" className="text-sm underline underline-offset-4">Privacy Policy</button>
            </DialogTrigger>
            <DialogContent className="sm:max-w-[625px] bg-black text-white border border-gray-800">
                <DialogHeader>
                    <DialogTitle className="text-2xl font-bold">Privacy Policy</DialogTitle>
                    <DialogDescription className="text-gray-400">
                        LiteNet is committed to protecting your privacy. This Privacy Policy explains our practices regarding the collection, use, and disclosure of your information.
                    </DialogDescription>
                </DialogHeader>
                <ScrollArea className="h-[400px] w-full rounded-md border border-gray-800 p-4">
                    <h2 className="text-lg font-semibold mb-2">1. Information Collection and Use</h2>
                    <p className="mb-4">
                        Privacy is a primary goal of LiteNet. We collect and maintain only necessary information to ensure the safety and functionality of our system.
                    </p>

                    <h2 className="text-lg font-semibold mb-2">2. Call Detail Records (CDR) Logs</h2>
                    <p className="mb-4">
                        CDR Logs are accessible only by authorized personnel. These logs are used solely for system debugging purposes and to identify and block malicious callers. Access to these logs is strictly controlled and monitored.
                    </p>

                    <h2 className="text-lg font-semibold mb-2">3. Call Recording</h2>
                    <p className="mb-4">
                        Call recording does not happen on the LiteNet Phone system itself. Individuals may record their calls via their own methods provided it's legal in their jurisdiction. If you record your calls we ask you announce it before a conversation.
                    </p>

                    <h2 className="text-lg font-semibold mb-2">4. Voicemail Privacy</h2>
                    <p className="mb-4">
                        LiteNet does not track or monitor voicemails. Users can expect an inherent level of privacy when using the voicemail system. Voicemail messages are accessible only by the owner of the extension.
                    </p>

                    <h2 className="text-lg font-semibold mb-2">5. Data Deletion</h2>
                    <p className="mb-4">
                        Users have the right to request the deletion of their data at any time. This can be done by using the "Delete your extension" function within the user interface. Upon deletion, all relevant user information, including but not limited to login credentials, voicemail messages, and voicemail PIN numbers, will be immediately and permanently removed from our system.
                    </p>

                    <h2 className="text-lg font-semibold mb-2">6. Data Security</h2>
                    <p className="mb-4">
                        We implement a variety of security measures to maintain the safety of your personal information. However, no method of transmission over the Internet or method of electronic storage is 100% secure.
                    </p>

                    <h2 className="text-lg font-semibold mb-2">7. Changes to This Privacy Policy</h2>
                    <p className="mb-4">
                        We may update our Privacy Policy from time to time. We will notify you of any changes by posting the new Privacy Policy on this page and updating the "last updated" date.
                    </p>

                    <h2 className="text-lg font-semibold mb-2">8. Contact Us</h2>
                    <p className="mb-4">
                        If you have any questions or concerns regarding this Privacy Policy, please contact our staff members. They are available to assist you with any privacy-related inquiries.
                    </p>

                    <p className="mt-4 font-semibold">
                        By using LiteNet's services, you acknowledge that you have read and understood this Privacy Policy and agree to its terms.
                    </p>
                </ScrollArea>
            </DialogContent>
        </Dialog>
    )
}

