import Link from 'next/link';
import { updates } from '@/data/updates';
import Image from 'next/image';
import DateDisplay from './DateDisplay';

export default function Updates() {
  const recentUpdates = [...updates]
    .sort((a, b) => new Date(b.timestamp).getTime() - new Date(a.timestamp).getTime())
    .slice(0, 2);

  return (
    <section id="updates" className="container py-24">
      <div className="flex justify-between items-center mb-12">
        <h2 className="text-3xl font-bold">Latest Updates</h2>
        <Link 
          href="/updates" 
          className="text-blue-500 hover:underline inline-flex items-center"
        >
          View all updates →
        </Link>
      </div>

      <div className="grid gap-8 md:grid-cols-2">
        {recentUpdates.map(post => (
          <div key={post.id} className="group p-6 border border-gray-800 rounded-lg hover:border-blue-500 transition-colors">
            <div className="flex items-center gap-3 mb-4">
              <img
                src={post.author.avatar}
                alt={post.author.name}
                className="w-10 h-10 rounded-full"
                width={40}
                height={40}
              />
              <div>
                <h4 className="text-sm font-medium">{post.author.name}</h4>
                <p className="text-xs text-gray-400">{post.author.role}</p>
              </div>
            </div>
            <h3 className="text-2xl font-semibold mb-2">{post.title}</h3>
            <DateDisplay 
              timestamp={post.timestamp} 
              className="text-sm text-gray-400 mb-3 block"
            />
            <p className="text-gray-400 mb-4">{post.summary}</p>
            <Link 
              href={`/updates/${post.id}`}
              className="text-blue-500 hover:underline inline-flex items-center"
            >
              Read more →
            </Link>
          </div>
        ))}
      </div>
    </section>
  );
}
